@@ -1,36 +1,6 @@
-/* Copyright (C) 2008 Atsushi Togo */
-/* All rights reserved. */
-
-/* This file is part of spglib. */
-
-/* Redistribution and use in source and binary forms, with or without */
-/* modification, are permitted provided that the following conditions */
-/* are met: */
-
-/* * Redistributions of source code must retain the above copyright */
-/*   notice, this list of conditions and the following disclaimer. */
-
-/* * Redistributions in binary form must reproduce the above copyright */
-/*   notice, this list of conditions and the following disclaimer in */
-/*   the documentation and/or other materials provided with the */
-/*   distribution. */
-
-/* * Neither the name of the spglib project nor the names of its */
-/*   contributors may be used to endorse or promote products derived */
-/*   from this software without specific prior written permission. */
-
-/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS */
-/* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT */
-/* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS */
-/* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE */
-/* COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, */
-/* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, */
-/* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; */
-/* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER */
-/* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT */
-/* LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN */
-/* ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE */
-/* POSSIBILITY OF SUCH DAMAGE. */
+// Copyright (C) 2008 Atsushi Togo
+// This file is part of spglib.
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "spglib.h"
 #include "base.h"
@@ -203,32 +173,32 @@ static size_t get_dense_stabilized_reciprocal_mesh(
 /*-----------------------------------------*/
 /* Version: spglib-[major].[minor].[micro] */
 /*-----------------------------------------*/
-char const *spg_get_version() {
+char const *spg_get_version(void) {
     spglib_error_code = SPGLIB_SUCCESS;
     return SPGLIB_VERSION;
 }
 
-char const *spg_get_version_full() {
+char const *spg_get_version_full(void) {
     spglib_error_code = SPGLIB_SUCCESS;
     return SPGLIB_VERSION_FULL;
 }
 
-char const *spg_get_commit() {
+char const *spg_get_commit(void) {
     spglib_error_code = SPGLIB_SUCCESS;
     return SPGLIB_COMMIT;
 }
 
-int spg_get_major_version() {
+int spg_get_major_version(void) {
     spglib_error_code = SPGLIB_SUCCESS;
     return SPGLIB_MAJOR_VERSION;
 }
 
-int spg_get_minor_version() {
+int spg_get_minor_version(void) {
     spglib_error_code = SPGLIB_SUCCESS;
     return SPGLIB_MINOR_VERSION;
 }
 
-int spg_get_micro_version() {
+int spg_get_micro_version(void) {
     spglib_error_code = SPGLIB_SUCCESS;
     return SPGLIB_MICRO_VERSION;
 }
